@@ -1,6 +1,7 @@
 use strict; use warnings;
 package Acme::Math::XS;
-our $VERSION = -1;
+# our $VERSION = 'x.x.x';
+use Alt::Acme::Math::XS::EUMM;
 
 use Exporter 'import';
 our @EXPORT = qw(
